@@ -143,7 +143,8 @@ public:
 		OUTGOING,	/* outbound call */
 		PICKUP,		/* station pickup */
 		FORWARDED,	/* inbound forwarded call */
-		RECALL		/* inbound hold recall */
+		RECALL,		/* inbound hold recall */
+		DIRECT		/* node/endpoint direct */
 	}	calltype_t;
 
 	/**
@@ -282,8 +283,9 @@ public:
 
 		// primary session control events
 
-		START_SCRIPT = 200,	// start a script, incoming
-		START_SELECTED,		// start selected script, outbound
+		START_DIRECT = 200,	// start a script, directed
+		START_INCOMING,		// start an incoming script
+		START_OUTGOING,		// start selected script, outbound
 		START_RECALL,		// start a recalled call
 		START_FORWARDED,	// start a forwarded call
 		STOP_SCRIPT,
@@ -298,8 +300,8 @@ public:
 		CHILD_BUSY,
 		CHILD_FAX,
 
-		START_INCOMING = START_SCRIPT,
-		START_OUTGOING = START_SELECTED,
+		START_SCRIPT = START_INCOMING,
+		START_SELECTED = START_OUTGOING,
 
 		// libexec specific events
 
