@@ -365,6 +365,8 @@ const char *BayonneSession::getExternal(const char *id)
 			{
 			case NONE:
 				return "none";
+			case DIRECT:
+				return "direct";
 			case INCOMING:
 				return "incoming";
 			case OUTGOING:
@@ -716,7 +718,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	const char *id;
 	Name *scr = event->start.scr;
 	ScriptImage *img = event->start.img;
-	const char *did = NULL;
+	const char *did = NULL, *cid = NULL;
 	bool ref = false;
 	unsigned pri = 0;
 	Line *line;
@@ -757,6 +759,15 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	if(iface == IF_INET)
 		goto incoming;
 
+	cid = getSymbol("session.caller");
+	if(cid)
+	{
+		snprintf(buf, sizeof(buf), "cid.%s", cid);
+		scr = (Name *)img->getPointer(buf);
+		if(scr)
+			goto final;
+	}
+
 	snprintf(buf, sizeof(buf), "ts.%d", timeslot);
 	scr = (Name *)img->getPointer(buf);
 	if(scr)
@@ -852,8 +863,6 @@ final:
 	if(!did)
 		setConst("session.dialed", event->start.dialing);
 
-	setConst("session.auth", "none");
-
 	return scr;
 }
 	
