@@ -1333,6 +1333,9 @@ bool BayonneSession::stateRinging(Event *event)
 
 bool BayonneSession::stateIdle(Event *event)
 {
+	char buf[65];
+	const char *cid, *did, *cinfo;
+	
 	if(enterIdle(event))
 		return true;
 
@@ -1367,23 +1370,68 @@ bool BayonneSession::stateIdle(Event *event)
 	case START_FORWARDED:
 		type = FORWARDED;
 		goto attach;
+	case START_DIRECT:
+		type = DIRECT;
+		goto attach;
 	case START_INCOMING:
 		type = INCOMING;
 
 attach:
 		if(attachStart(event))
 		{
+			did = getSymbol("session.dialed");
+			cid = getSymbol("session.caller");
+			cinfo = getSymbol("session.info");
 			switch(type)
 			{
+			case DIRECT:
+				if(cinfo && *cinfo)
+				{
+					snprintf(buf, sizeof(buf), "info:%s", cinfo);
+					scriptEvent(buf);
+				}
+				type = INCOMING;
+				break;
 			case FORWARDED:
+				if(did && *did)
+				{
+					snprintf(buf, sizeof(buf), "forwarded:%s", did);
+					if(digitEvent(buf))
+						break;
+				}
 				scriptEvent("incoming:forward");
 				break;
 			case RECALL:
 				scriptEvent("incoming:recall");
 				break;
 			case PICKUP:
+				if(cid && *cid)
+				{
+					snprintf(buf, sizeof(buf), "pickup:%s", cid);
+					if(digitEvent(buf))
+						break;
+				}
 				scriptEvent("incoming:pickup");
 				break;
+			case INCOMING:
+				if(cinfo && *cinfo)
+				{
+					snprintf(buf, sizeof(buf), "info:%s", cinfo);
+					if(scriptEvent(buf))
+						break;
+				}
+				if(did && *did)
+				{
+					snprintf(buf, sizeof(buf), "dialed:%s", did);
+					if(digitEvent(buf))
+						break;
+				}
+				if(cid && *cid)
+				{
+					snprintf(buf, sizeof(buf), "caller:%s", cid);
+					if(digitEvent(buf))
+						break;
+				}
 			default:
 				if(ring_count)
 					scriptEvent("incoming:ringing");
@@ -1610,6 +1658,7 @@ bool BayonneSession::stateRunning(Event *event)
 			event->id = ENTER_STATE;
 			if(seizure != CHILD_RUNNING)
 				strcpy(var_pid, "none");
+			setConst("session.callref", var_sid);
 		}
 		if(state.pid)
 			newTid();
