@@ -778,6 +778,9 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 	if(!stricmp(line->cmd, "incoming"))
 		goto dnis;
 
+	if(!stricmp(line->cmd, "caller"))
+		goto cid;
+
 	if(!stricmp(line->cmd, "incoming.timeslot"))
 		goto timeslot;
 
@@ -804,6 +807,9 @@ const char *Checks::chkAssign(Line *line, ScriptImage *img)
 		if(!stricmp(cp, "did"))
 			goto dnis;
 
+		if(!stricmp(cp, "cid"))
+			goto cid;
+
 		driver = BayonneDriver::get(cp);
 		if(!driver)
 		{
@@ -845,6 +851,16 @@ span:
 		img->setPointer(tag, scr);
 	}
 	return "";
+
+cid:
+	while(NULL != (cp = getOption(line, &idx)))
+	{
+		slog.debug("assigning caller number %s to %s", cp, scr->name);
+		snprintf(tag, sizeof(tag), "cid.%s", cp);
+		img->setPointer(tag, scr);
+	}
+	return "";
+
 dnis:
         while(NULL != (cp = getOption(line, &idx)))
         {
