@@ -548,6 +548,12 @@ retry:
                 goto retry;
         }
 
+	if(!strnicmp(option, "-scripts=", 9))
+	{
+		runtime.setValue("scripts", option + 9);
+		++argv;
+		goto retry;
+	}
 
 	if(!strnicmp(option, "-macros=", 8))
 	{
@@ -563,7 +569,6 @@ retry:
                 goto retry;
         }
             
-
 	if(!stricmp(option, "-check"))
 	{
 		live = false;
@@ -652,12 +657,25 @@ retry:
                 goto retry;
         }
 
+        if(!stricmp(option, "-scripts"))     
+        {
+                ++argv;
+                if(!*argv)
+                {
+			cerr << "bayonne: " << cmd << ": -scripts: missing argument" << endl;
+                        exit(-1);
+                }
+                runtime.setValue("scripts", *(argv++));
+                goto retry;
+        }
+           
+
         if(!stricmp(option, "-macros"))     
         {
                 ++argv;
                 if(!*argv)
                 {
-                        cerr << "bayonne: " << cmd << ": -macros: missing argument" << endl;
+			cerr << "bayonne: " << cmd << ": -macros: missing argument" << endl;
                         exit(-1);
                 }
                 runtime.setValue("include", *(argv++));
@@ -832,7 +850,7 @@ skip:
 			else
 				keyoptions.setValue("modules", path);
 		}
-		else if(!stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
+		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
 		{
 			prefix = strrchr(*argv, '/');
 			if(!prefix)
@@ -867,9 +885,12 @@ skip:
 
 	Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime));
 
-	if(!script)
+	if(!script) 
 	{
-		runtime.setValue("scripts", keypaths.getLast("scripts"));
+		if(!runtime.getLast("scripts"))
+			runtime.setValue("scripts", keypaths.getLast("scripts"));
+		if(keypaths.getLast("addons"))
+			runtime.setValue("addons", keypaths.getLast("addons"));
 		return false;
 	}
 
